@@ -1,17 +1,17 @@
+from __future__ import annotations
+
 import argparse
-from typing import List
-from typing import Optional
 from typing import Sequence
 
 from all_repos import autofix_lib
 from all_repos.config import Config
 
 
-def find_repos(_: Config) -> List[str]:
+def find_repos(_: Config) -> list[str]:
     raise AssertionError('--repos is required')
 
 
-def main(argv: Optional[Sequence[str]] = None) -> int:
+def main(argv: Sequence[str] | None = None) -> int:
     parser = argparse.ArgumentParser(
         description='Interactively apply a manual change across repos.',
         usage='%(prog)s [options]',
@@ -48,4 +48,4 @@ def main(argv: Optional[Sequence[str]] = None) -> int:
 
 
 if __name__ == '__main__':
-    exit(main())
+    raise SystemExit(main())
